@@ -4,9 +4,8 @@ from django.utils.translation import get_language
 from django.utils.translation import ugettext_lazy as _
 
 from cmsplugin_blog.admin import EntryAdmin
-from cmsplugin_blog.models import Entry
 from simple_translation.admin import TranslationAdmin
-from simple_translation.utils import get_translation_queryset
+from simple_translation.utils import get_preferred_translation_from_lang
 
 from cmsplugin_blog_categories.models import Category, EntryCategory
 
@@ -20,15 +19,15 @@ class EntryCategoryAdmin(admin.ModelAdmin):
     list_display = ['entry_title', 'category_title', ]
 
     def category_title(self, obj):
-        lang = get_language()
-        return get_translation_queryset(obj.category).filter(
-            language=lang)[0].title
+        """Returns the best available translation for the category title."""
+        return obj.category.get_translation().title
     category_title.short_description = _('Category')
 
     def entry_title(self, obj):
+        """Returns the best available translation for the entry title."""
         lang = get_language()
-        return get_translation_queryset(obj.entry).filter(
-            language=lang)[0].title
+        entry_title = get_preferred_translation_from_lang(obj.entry, lang)
+        return entry_title.title
     entry_title.short_description = _('Entry title')
 
 
@@ -36,8 +35,8 @@ class CategoryAdmin(TranslationAdmin):
     list_display = ['title', 'languages', ]
 
     def title(self, obj):
-        lang = get_language()
-        return get_translation_queryset(obj).filter(language=lang)[0].title
+        """Returns the best available translation for the catrgory title."""
+        return obj.get_translation().title
     title.short_description = _('Title')
 
 
