@@ -13,10 +13,8 @@ class CMSCategoryPlugin(CMSPluginBase):
     render_template = 'cmsplugin_blog_categories/category_plugin.html'
 
     def render(self, context, instance, placeholder):
-        entries = instance.category.get_entries()
         context.update({
-            'category': instance.category,
-            'category_entries': entries,
+            'categories': instance.categories.all(),
             'placeholder': placeholder,
         })
         return context
